import { Texture } from '@luma.gl/core';
import { AmbientLight } from "./ambient-light.js";
import { DirectionalLight } from "./directional-light.js";
import { PointLight } from "./point-light.js";
import { Matrix4 } from '@math.gl/core';
import type Layer from "../../lib/layer.js";
import type { Effect, EffectContext, PreRenderOptions } from "../../lib/effect.js";
export type LightingEffectProps = Record<string, PointLight | DirectionalLight | AmbientLight>;
export default class LightingEffect implements Effect {
    id: string;
    props: LightingEffectProps;
    shadowColor: number[];
    context?: EffectContext;
    private shadow;
    private ambientLight?;
    private directionalLights;
    private pointLights;
    private shadowPasses;
    private shadowMaps;
    private dummyShadowMap;
    private shadowMatrices?;
    constructor(props?: LightingEffectProps);
    setup(context: EffectContext): void;
    setProps(props: LightingEffectProps): void;
    preRender({ layers, layerFilter, viewports, onViewportActive, views }: PreRenderOptions): void;
    getModuleParameters(layer: Layer): {
        lightSources?: {
            ambientLight?: AmbientLight | null | undefined;
            directionalLights: DirectionalLight[];
            pointLights: PointLight[];
        } | undefined;
        shadowMaps?: Texture<import("@luma.gl/core").TextureProps>[] | undefined;
        dummyShadowMap?: Texture<import("@luma.gl/core").TextureProps> | null | undefined;
        shadowColor?: number[] | undefined;
        shadowMatrices?: Matrix4[] | undefined;
    };
    cleanup(context: EffectContext): void;
    private _calculateMatrices;
    private _createShadowPasses;
    private _applyDefaultLights;
}
//# sourceMappingURL=lighting-effect.d.ts.map